==> tr-2.2.1.zip: tr/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'hayır';
$GLOBALS['__l10n']['blog settings'] = 'blog ayarları';
$GLOBALS['__l10n']['Value'] = 'Değer';
$GLOBALS['__l10n']['Description'] = 'Açıklama';
$GLOBALS['__l10n']['global settings'] = 'global ayarlar';
$GLOBALS['__l10n']['Blacklist'] = 'Karaliste';
$GLOBALS['__l10n']['Whitelist'] = 'Beyazliste';
$GLOBALS['__l10n']['Add a word'] = 'Kelime ekle';
$GLOBALS['__l10n']['List'] = 'Liste';
$GLOBALS['__l10n']['Send'] = 'Gönder';
$GLOBALS['__l10n']['Import a single blog'] = 'Tek bir blog içe aktar.';
$GLOBALS['__l10n']['Maintenance'] = 'Bakım';
$GLOBALS['__l10n']['next'] = 'diğeri';
$GLOBALS['__l10n']['Back'] = 'Geri';
$GLOBALS['__l10n']['Search engine index'] = 'Arama motoru indeksi';
$GLOBALS['__l10n']['Index all posts'] = 'Tüm yazıları indeksle';
$GLOBALS['__l10n']['Pages'] = 'Sayfalar';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Geçerli bir eposta adresi girmelisiniz.';
$GLOBALS['__l10n']['Page title'] = 'Sayfa başlığı';
$GLOBALS['__l10n']['Tags'] = 'Etiketler';
$GLOBALS['__l10n']['Tags:'] = 'Etiketler:';
$GLOBALS['__l10n']['all'] = 'tümü';
$GLOBALS['__l10n']['Tag'] = 'Etiket';
$GLOBALS['__l10n']['Add tags'] = 'tag ekle';
$GLOBALS['__l10n']['Remove tags'] = 'tag sil';
$GLOBALS['__l10n']['Tags to add:'] = 'Eklenecek tagler:';
$GLOBALS['__l10n']['Tags list format:'] = 'Eklenecek tagler:';
$GLOBALS['__l10n']['All tags'] = 'Tüm etiketler';
$GLOBALS['__l10n']['Edit tag'] = 'Tag düzenle';
$GLOBALS['__l10n']['Document saved'] = 'Belge kaydedildi.';
$GLOBALS['__l10n']['Selected entries'] = 'Seçtiğim girimler.';
$GLOBALS['__l10n']['Best of me'] = 'En iyilerim';
$GLOBALS['__l10n']['Blog languages'] = 'Blog dilleri';
$GLOBALS['__l10n']['Last comments'] = 'Son ahkamlar';
$GLOBALS['__l10n']['Archives'] = 'Arşiv';
$GLOBALS['__l10n']['Setting name:'] = 'Ayar adı:';
$GLOBALS['__l10n']['order'] = 'sıra';
?>

==> tr-2.3.1.zip: tr/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'hayır';
$GLOBALS['__l10n']['blog settings'] = 'blog ayarları';
$GLOBALS['__l10n']['Value'] = 'Değer';
$GLOBALS['__l10n']['Description'] = 'Açıklama';
$GLOBALS['__l10n']['global settings'] = 'global ayarlar';
$GLOBALS['__l10n']['Blacklist'] = 'Karaliste';
$GLOBALS['__l10n']['Whitelist'] = 'Beyazliste';
$GLOBALS['__l10n']['Add a word'] = 'Kelime ekle';
$GLOBALS['__l10n']['List'] = 'Liste';
$GLOBALS['__l10n']['position'] = 'Açıklama';
$GLOBALS['__l10n']['Send'] = 'Gönder';
$GLOBALS['__l10n']['Import a single blog'] = 'Tek bir blog içe aktar.';
$GLOBALS['__l10n']['Maintenance'] = 'Bakım';
$GLOBALS['__l10n']['next'] = 'diğeri';
$GLOBALS['__l10n']['Back'] = 'Geri';
$GLOBALS['__l10n']['Search engine index'] = 'Arama motoru indeksi';
$GLOBALS['__l10n']['Index all posts'] = 'Tüm yazıları indeksle';
$GLOBALS['__l10n']['%d pages'] = 'Sayfalar';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Geçerli bir eposta adresi girmelisiniz.';
$GLOBALS['__l10n']['Page title'] = 'Sayfa başlığı';
$GLOBALS['__l10n']['Tags'] = 'Etiketler';
$GLOBALS['__l10n']['Tags:'] = 'Etiketler:';
$GLOBALS['__l10n']['all'] = 'tümü';
$GLOBALS['__l10n']['Tag'] = 'Etiket';
$GLOBALS['__l10n']['Add tags'] = 'tag ekle';
$GLOBALS['__l10n']['Remove tags'] = 'tag sil';
$GLOBALS['__l10n']['Tags to add:'] = 'Eklenecek tagler:';
$GLOBALS['__l10n']['Tags list format:'] = 'Eklenecek tagler:';
$GLOBALS['__l10n']['All tags'] = 'Tüm etiketler';
$GLOBALS['__l10n']['Edit tag'] = 'Tag düzenle';
$GLOBALS['__l10n']['Document saved'] = 'Belge kaydedildi.';
$GLOBALS['__l10n']['global preferences'] = 'global ayarlar';
$GLOBALS['__l10n']['Selected entries'] = 'Seçtiğim girimler.';
$GLOBALS['__l10n']['Best of me'] = 'En iyilerim';
$GLOBALS['__l10n']['Blog languages'] = 'Blog dilleri';
$GLOBALS['__l10n']['Last comments'] = 'Son ahkamlar';
$GLOBALS['__l10n']['Archives'] = 'Arşiv';
$GLOBALS['__l10n']['Setting name:'] = 'Ayar adı:';
$GLOBALS['__l10n']['order'] = 'sıra';
?>
